@@ -1,6 +1,7 @@
 use strict;
 use Spreadsheet::ParseExcel;
 use Spreadsheet::ParseExcel::FmtJapan;
+sub PrnBook($);
 #0. Check ARGV
 if(($#ARGV< 0) or 
    (grep($ARGV[0] eq $_, ('euc', 'sjis', 'jis')) <= 0)) {
@@ -36,7 +37,7 @@ PrnBook($oBook);
 $oBook = $oExcel->Parse('Excel/AuthorK95.xls', $oFmtJ);
 PrnBook($oBook);
 
-sub PrnBook($$)
+sub PrnBook($)
 {
     my($oBook) = @_;
     my($iR, $iC, $oWkS, $oWkC);
@@ -53,7 +54,7 @@ sub PrnBook($$)
             for(my $iC = $oWkS->{MinCol} ;
                             defined $oWkS->{MaxCol} && $iC <= $oWkS->{MaxCol} ; $iC++) {
                 $oWkC = $oWkS->{Cells}[$iR][$iC];
-                print "( $iR , $iC ) =>", $oWkC->Value, "\n";
+                print "( $iR , $iC ) =>", $oWkC->Value, "\n" if($oWkC);
             }
         }
     }
